﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;

namespace TestProject;

/// <summary>
/// 이미지 버튼
/// </summary>
public class ImageButton : Button
{
    //////////////////////////////////////////////////////////////////////////////////////////////////// Dependency Property
    ////////////////////////////////////////////////////////////////////////////////////////// Statc
    //////////////////////////////////////////////////////////////////////////////// Statc

    #region 이미지 너비 속성 - ImageWidthProperty

    /// <summary>
    /// 이미지 너비 속성
    /// </summary>
    public static readonly DependencyProperty ImageWidthProperty = DependencyProperty.Register
    (
        "ImageWidth",
        typeof(double),
        typeof(ImageButton),
        new PropertyMetadata(32.0)
    );

    #endregion
    #region 이미지 높이 속성 - ImageHeightProperty

    /// <summary>
    /// 이미지 높이 속성
    /// </summary>
    public static readonly DependencyProperty ImageHeightProperty = DependencyProperty.Register
    (
        "ImageHeight",
        typeof(double),
        typeof(ImageButton),
        new PropertyMetadata(32.0)
    );

    #endregion
    #region 이용 가능 이미지 소스 속성 - EnabledImageSourceProperty

    /// <summary>
    /// 이용 가능 이미지 소스 속성
    /// </summary>
    public static readonly DependencyProperty EnabledImageSourceProperty = DependencyProperty.Register
    (
        "EnabledImageSource",
        typeof(ImageSource),
        typeof(ImageButton),
        new PropertyMetadata(null)
    );

    #endregion
    #region 이용 불가 이미지 소스 속성 - DisabledImageSourceProperty

    /// <summary>
    /// 이용 불가 이미지 소스 속성
    /// </summary>
    public static readonly DependencyProperty DisabledImageSourceProperty = DependencyProperty.Register
    (
        "DisabledImageSource",
        typeof(ImageSource),
        typeof(ImageButton),
        new PropertyMetadata(null)
    );

    #endregion

    //////////////////////////////////////////////////////////////////////////////////////////////////// Property
    ////////////////////////////////////////////////////////////////////////////////////////// Public

    #region 이미지 너비 - ImageWidth

    /// <summary>
    /// 이미지 너비
    /// </summary>
    public double ImageWidth
    {
        get => (double)GetValue(ImageWidthProperty);
        set => SetValue(ImageWidthProperty, value);
    }

    #endregion
    #region 이미지 높이 - ImageHeight

    /// <summary>
    /// 이미지 높이
    /// </summary>
    public double ImageHeight
    {
        get => (double)GetValue(ImageHeightProperty);
        set => SetValue(ImageHeightProperty, value);
    }

    #endregion
    #region 이용 가능 이미지 소스 - EnabledImageSource

    /// <summary>
    /// 이용 가능 이미지 소스
    /// </summary>
    public ImageSource EnabledImageSource
    {
        get => (ImageSource)GetValue(EnabledImageSourceProperty);
        set => SetValue(EnabledImageSourceProperty, value);
    }

    #endregion
    #region 이용 불가 이미지 소스 - DisabledImageSource

    /// <summary>
    /// 이용 불가 이미지 소스
    /// </summary>
    public ImageSource DisabledImageSource
    {
        get => (ImageSource)GetValue(DisabledImageSourceProperty);
        set => SetValue(DisabledImageSourceProperty, value);
    }

    #endregion

    //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
    ////////////////////////////////////////////////////////////////////////////////////////// Statc

    #region 생성자 - ImageButton

    /// <summary>
    /// 생성자
    /// </summary>
    static ImageButton()
    {
        DefaultStyleKeyProperty.OverrideMetadata(typeof(ImageButton), new FrameworkPropertyMetadata(typeof(ImageButton)));
    }

    #endregion
}